==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TypicalPriceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TypicalPriceIndicatorDescription } from "./TypicalPriceIndicatorDescription";
/**
 * @hidden
 */
var TypicalPriceIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicatorDescriptionMetadata, _super);
    function TypicalPriceIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicatorDescriptionMetadata.b = function (a) {
        if (TypicalPriceIndicatorDescriptionMetadata.a == null) {
            TypicalPriceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TypicalPriceIndicatorDescriptionMetadata.c(TypicalPriceIndicatorDescriptionMetadata.a);
        }
        if (a.g(TypicalPriceIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(TypicalPriceIndicatorDescriptionMetadata.a);
    };
    TypicalPriceIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    TypicalPriceIndicatorDescriptionMetadata.d = function (a) {
        TypicalPriceIndicatorDescriptionMetadata.b(a);
        a.u("TypicalPriceIndicator", function () { return new TypicalPriceIndicatorDescription(); });
        a.t("TypicalPriceIndicator", TypicalPriceIndicatorDescriptionMetadata.a);
    };
    TypicalPriceIndicatorDescriptionMetadata.$t = markType(TypicalPriceIndicatorDescriptionMetadata, 'TypicalPriceIndicatorDescriptionMetadata');
    TypicalPriceIndicatorDescriptionMetadata.a = null;
    return TypicalPriceIndicatorDescriptionMetadata;
}(Base));
export { TypicalPriceIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TypicalPriceIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { TypicalPriceIndicatorDescription } from "./TypicalPriceIndicatorDescription";
/**
 * @hidden
 */
var TypicalPriceIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TypicalPriceIndicatorDescriptionMetadata, _super);
    function TypicalPriceIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TypicalPriceIndicatorDescriptionMetadata.b = function (a) {
        if (TypicalPriceIndicatorDescriptionMetadata.a == null) {
            TypicalPriceIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TypicalPriceIndicatorDescriptionMetadata.c(TypicalPriceIndicatorDescriptionMetadata.a);
        }
        if (a.j(TypicalPriceIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(TypicalPriceIndicatorDescriptionMetadata.a);
    };
    TypicalPriceIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    TypicalPriceIndicatorDescriptionMetadata.d = function (a) {
        TypicalPriceIndicatorDescriptionMetadata.b(a);
        a.aa("TypicalPriceIndicator", function () { return new TypicalPriceIndicatorDescription(); });
        a.z("TypicalPriceIndicator", TypicalPriceIndicatorDescriptionMetadata.a);
    };
    TypicalPriceIndicatorDescriptionMetadata.$t = markType(TypicalPriceIndicatorDescriptionMetadata, 'TypicalPriceIndicatorDescriptionMetadata');
    TypicalPriceIndicatorDescriptionMetadata.a = null;
    return TypicalPriceIndicatorDescriptionMetadata;
}(Base));
export { TypicalPriceIndicatorDescriptionMetadata };
